# openai-api-with-easy-tools-and-web-browsing
An unofficial OpenAI library for Python, featuring an integrated Bing Custom Search API for web browsing (free) and easy-to-use custom tools.

See example below for a quick start.
